==> cost-interface-0.3.24-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/regist/CountryPlaneAdRegistVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.regist;

import java.io.Serializable;
import java.util.Date;

/**
 * 全国面上广告登记
 * CountryPlaneAdRegist
 * 数据库表：country_plane_ad_regist
 */
public class CountryPlaneAdRegistVo implements Serializable {

    private static final long serialVersionUID = -4924992358206895492L;
    /**
     *
     * 表字段 : country_plane_ad_regist.id
     */
    private Integer id;

    /**
     * 行项目号
     * 表字段 : country_plane_ad_regist.item_no
     */
    private Integer itemNo;

    /**
     * 登记单号
     * 表字段 : country_plane_ad_regist.regist_no
     */
    private String registNo;

    /**
     * 申请单号
     * 表字段 : country_plane_ad_regist.apply_no
     */
    private String applyNo;

    /**
     * 申请单行项目号
     * 表字段 : country_plane_ad_regist.apply_item_no
     */
    private Integer applyItemNo;

    /**
     * 费用类型编码
     * 表字段 : country_plane_ad_regist.cost_type_id
     */
    private String costTypeId;

    /**
     * 费用类型名称
     * 表字段 : country_plane_ad_regist.cost_type_name
     */
    private String costTypeName;

    /**
     * 媒体大类
     * 表字段 : country_plane_ad_regist.media_big_code
     */
    private String mediaBigCode;

    /**
     * 媒体大类名称
     * 表字段 : country_plane_ad_regist.media_big_name
     */
    private String mediaBigName;

    /**
     * 媒体小类
     * 表字段 : country_plane_ad_regist.media_small_code
     */
    private String mediaSmallCode;

    /**
     * 媒体小类名称
     * 表字段 : country_plane_ad_regist.media_small_name
     */
    private String mediaSmallName;

    /**
     * 媒体内容
     * 表字段 : country_plane_ad_regist.media_content
     */
    private String mediaContent;

    /**
     * 开始日期
     * 表字段 : country_plane_ad_regist.s_date
     */
    private Date sDate;

    /**
     * 结束日期
     * 表字段 : country_plane_ad_regist.e_date
     */
    private Date eDate;

    /**
     * 推广品牌编码
     * 表字段 : country_plane_ad_regist.brand_id
     */
    private String brandId;

    /**
     * 推广品牌名称
     * 表字段 : country_plane_ad_regist.brand_name
     */
    private String brandName;

    /**
     * 数量
     * 表字段 : country_plane_ad_regist.count
     */
    private Integer count;

    /**
     * 实施方
     * 表字段 : country_plane_ad_regist.implementing_party
     */
    private String implementingParty;

    /**
     * 联系人
     * 表字段 : country_plane_ad_regist.contacts
     */
    private String contacts;

    /**
     * 联系方式
     * 表字段 : country_plane_ad_regist.contact_way
     */
    private String contactWay;

    /**
     * 活动形式
     * 表字段 : country_plane_ad_regist.activity_forms
     */
    private String activityForms;

    /**
     * 厂方承担金额(分)
     * 表字段 : country_plane_ad_regist.company_amount
     */
    private Long companyAmount;

    /**
     * 备注
     * 表字段 : country_plane_ad_regist.notes
     */
    private String notes;

    /**
     * 行项目余额
     * 表字段 : country_plane_ad_regist.item_balance
     */
    private Long itemBalance;

    /**
     * 督查意见
     * 表字段 : country_plane_ad_regist.audit_notes
     */
    private String auditNotes;

    /**
     *
     * 表字段 : country_plane_ad_regist.create_id
     */
    private String createId;

    /**
     *
     * 表字段 : country_plane_ad_regist.create_name
     */
    private String createName;

    /**
     *
     * 表字段 : country_plane_ad_regist.create_date
     */
    private Date createDate;

    /**
     *
     * 表字段 : country_plane_ad_regist.modify_id
     */
    private String modifyId;

    /**
     *
     * 表字段 : country_plane_ad_regist.modify_name
     */
    private String modifyName;

    /**
     *
     * 表字段 : country_plane_ad_regist.modify_date
     */
    private Date modifyDate;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getItemNo() {
        return itemNo;
    }

    public void setItemNo(Integer itemNo) {
        this.itemNo = itemNo;
    }

    public String getRegistNo() {
        return registNo;
    }

    public void setRegistNo(String registNo) {
        this.registNo = registNo;
    }

    public String getApplyNo() {
        return applyNo;
    }

    public void setApplyNo(String applyNo) {
        this.applyNo = applyNo;
    }

    public Integer getApplyItemNo() {
        return applyItemNo;
    }

    public void setApplyItemNo(Integer applyItemNo) {
        this.applyItemNo = applyItemNo;
    }

    public String getCostTypeId() {
        return costTypeId;
    }

    public void setCostTypeId(String costTypeId) {
        this.costTypeId = costTypeId;
    }

    public String getCostTypeName() {
        return costTypeName;
    }

    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }

    public String getMediaBigCode() {
        return mediaBigCode;
    }

    public void setMediaBigCode(String mediaBigCode) {
        this.mediaBigCode = mediaBigCode;
    }

    public String getMediaBigName() {
        return mediaBigName;
    }

    public void setMediaBigName(String mediaBigName) {
        this.mediaBigName = mediaBigName;
    }

    public String getMediaSmallCode() {
        return mediaSmallCode;
    }

    public void setMediaSmallCode(String mediaSmallCode) {
        this.mediaSmallCode = mediaSmallCode;
    }

    public String getMediaSmallName() {
        return mediaSmallName;
    }

    public void setMediaSmallName(String mediaSmallName) {
        this.mediaSmallName = mediaSmallName;
    }

    public String getMediaContent() {
        return mediaContent;
    }

    public void setMediaContent(String mediaContent) {
        this.mediaContent = mediaContent;
    }

    public Date getsDate() {
        return sDate;
    }

    public void setsDate(Date sDate) {
        this.sDate = sDate;
    }

    public Date geteDate() {
        return eDate;
    }

    public void seteDate(Date eDate) {
        this.eDate = eDate;
    }

    public String getBrandId() {
        return brandId;
    }

    public void setBrandId(String brandId) {
        this.brandId = brandId;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    public Integer getCount() {
        return count;
    }

    public void setCount(Integer count) {
        this.count = count;
    }

    public String getImplementingParty() {
        return implementingParty;
    }

    public void setImplementingParty(String implementingParty) {
        this.implementingParty = implementingParty;
    }

    public String getContacts() {
        return contacts;
    }

    public void setContacts(String contacts) {
        this.contacts = contacts;
    }

    public String getContactWay() {
        return contactWay;
    }

    public void setContactWay(String contactWay) {
        this.contactWay = contactWay;
    }

    public String getActivityForms() {
        return activityForms;
    }

    public void setActivityForms(String activityForms) {
        this.activityForms = activityForms;
    }

    public Long getCompanyAmount() {
        return companyAmount;
    }

    public void setCompanyAmount(Long companyAmount) {
        this.companyAmount = companyAmount;
    }

    public String getNotes() {
        return notes;
    }

    public void setNotes(String notes) {
        this.notes = notes;
    }

    public Long getItemBalance() {
        return itemBalance;
    }

    public void setItemBalance(Long itemBalance) {
        this.itemBalance = itemBalance;
    }

    public String getAuditNotes() {
        return auditNotes;
    }

    public void setAuditNotes(String auditNotes) {
        this.auditNotes = auditNotes;
    }

    public String getCreateId() {
        return createId;
    }

    public void setCreateId(String createId) {
        this.createId = createId;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getModifyId() {
        return modifyId;
    }

    public void setModifyId(String modifyId) {
        this.modifyId = modifyId;
    }

    public String getModifyName() {
        return modifyName;
    }

    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    public Date getModifyDate() {
        return modifyDate;
    }

    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }
}

==> cost-interface-0.3.45-sources.jar: com/chinayanghe/tpm/cost/vo/out/datadetail/regist/CountryPlaneAdRegistVo.java <==
package com.chinayanghe.tpm.cost.vo.out.datadetail.regist;

import java.io.Serializable;
import java.util.Date;

/**
 * 全国面上广告登记
 * CountryPlaneAdRegist
 * 数据库表：country_plane_ad_regist
 */
public class CountryPlaneAdRegistVo implements Serializable {

    private static final long serialVersionUID = -4924992358206895492L;
    /**
     *
     * 表字段 : country_plane_ad_regist.id
     */
    private Integer id;

    /**
     * 行项目号
     * 表字段 : country_plane_ad_regist.item_no
     */
    private Integer itemNo;

    /**
     * 登记单号
     * 表字段 : country_plane_ad_regist.regist_no
     */
    private String registNo;

    /**
     * 申请单号
     * 表字段 : country_plane_ad_regist.apply_no
     */
    private String applyNo;

    /**
     * 申请单行项目号
     * 表字段 : country_plane_ad_regist.apply_item_no
     */
    private Integer applyItemNo;

    /**
     * 费用类型编码
     * 表字段 : country_plane_ad_regist.cost_type_id
     */
    private String costTypeId;

    /**
     * 费用类型名称
     * 表字段 : country_plane_ad_regist.cost_type_name
     */
    private String costTypeName;

    /**
     * 媒体大类
     * 表字段 : country_plane_ad_regist.media_big_code
     */
    private String mediaBigCode;

    /**
     * 媒体大类名称
     * 表字段 : country_plane_ad_regist.media_big_name
     */
    private String mediaBigName;

    /**
     * 媒体小类
     * 表字段 : country_plane_ad_regist.media_small_code
     */
    private String mediaSmallCode;

    /**
     * 媒体小类名称
     * 表字段 : country_plane_ad_regist.media_small_name
     */
    private String mediaSmallName;

    /**
     * 媒体内容
     * 表字段 : country_plane_ad_regist.media_content
     */
    private String mediaContent;

    /**
     * 开始日期
     * 表字段 : country_plane_ad_regist.s_date
     */
    private Date sDate;

    /**
     * 结束日期
     * 表字段 : country_plane_ad_regist.e_date
     */
    private Date eDate;

    /**
     * 推广品牌编码
     * 表字段 : country_plane_ad_regist.brand_id
     */
    private String brandId;

    /**
     * 推广品牌名称
     * 表字段 : country_plane_ad_regist.brand_name
     */
    private String brandName;

    /**
     * 数量
     * 表字段 : country_plane_ad_regist.count
     */
    private Integer count;

    /**
     * 实施方
     * 表字段 : country_plane_ad_regist.implementing_party
     */
    private String implementingParty;

    /**
     * 联系人
     * 表字段 : country_plane_ad_regist.contacts
     */
    private String contacts;

    /**
     * 联系方式
     * 表字段 : country_plane_ad_regist.contact_way
     */
    private String contactWay;

    /**
     * 活动形式
     * 表字段 : country_plane_ad_regist.activity_forms
     */
    private String activityForms;

    /**
     * 实际发生金额(分)
     * 表字段 : country_plane_ad_regist.activity_amount
     */
    private Long activityAmount;

    /**
     * 厂方承担金额(分)
     * 表字段 : country_plane_ad_regist.company_amount
     */
    private Long companyAmount;

    /**
     * 备注
     * 表字段 : country_plane_ad_regist.notes
     */
    private String notes;

    /**
     * 行项目余额
     * 表字段 : country_plane_ad_regist.item_balance
     */
    private Long itemBalance;

    /**
     * 督查意见
     * 表字段 : country_plane_ad_regist.audit_notes
     */
    private String auditNotes;

    /**
     *
     * 表字段 : country_plane_ad_regist.create_id
     */
    private String createId;

    /**
     *
     * 表字段 : country_plane_ad_regist.create_name
     */
    private String createName;

    /**
     *
     * 表字段 : country_plane_ad_regist.create_date
     */
    private Date createDate;

    /**
     *
     * 表字段 : country_plane_ad_regist.modify_id
     */
    private String modifyId;

    /**
     *
     * 表字段 : country_plane_ad_regist.modify_name
     */
    private String modifyName;

    /**
     *
     * 表字段 : country_plane_ad_regist.modify_date
     */
    private Date modifyDate;

    public Integer getId() {
        return id;
    }

    public void setId(Integer id) {
        this.id = id;
    }

    public Integer getItemNo() {
        return itemNo;
    }

    public void setItemNo(Integer itemNo) {
        this.itemNo = itemNo;
    }

    public String getRegistNo() {
        return registNo;
    }

    public void setRegistNo(String registNo) {
        this.registNo = registNo;
    }

    public String getApplyNo() {
        return applyNo;
    }

    public void setApplyNo(String applyNo) {
        this.applyNo = applyNo;
    }

    public Integer getApplyItemNo() {
        return applyItemNo;
    }

    public void setApplyItemNo(Integer applyItemNo) {
        this.applyItemNo = applyItemNo;
    }

    public String getCostTypeId() {
        return costTypeId;
    }

    public void setCostTypeId(String costTypeId) {
        this.costTypeId = costTypeId;
    }

    public String getCostTypeName() {
        return costTypeName;
    }

    public void setCostTypeName(String costTypeName) {
        this.costTypeName = costTypeName;
    }

    public String getMediaBigCode() {
        return mediaBigCode;
    }

    public void setMediaBigCode(String mediaBigCode) {
        this.mediaBigCode = mediaBigCode;
    }

    public String getMediaBigName() {
        return mediaBigName;
    }

    public void setMediaBigName(String mediaBigName) {
        this.mediaBigName = mediaBigName;
    }

    public String getMediaSmallCode() {
        return mediaSmallCode;
    }

    public void setMediaSmallCode(String mediaSmallCode) {
        this.mediaSmallCode = mediaSmallCode;
    }

    public String getMediaSmallName() {
        return mediaSmallName;
    }

    public void setMediaSmallName(String mediaSmallName) {
        this.mediaSmallName = mediaSmallName;
    }

    public String getMediaContent() {
        return mediaContent;
    }

    public void setMediaContent(String mediaContent) {
        this.mediaContent = mediaContent;
    }

    public Date getsDate() {
        return sDate;
    }

    public void setsDate(Date sDate) {
        this.sDate = sDate;
    }

    public Date geteDate() {
        return eDate;
    }

    public void seteDate(Date eDate) {
        this.eDate = eDate;
    }

    public String getBrandId() {
        return brandId;
    }

    public void setBrandId(String brandId) {
        this.brandId = brandId;
    }

    public String getBrandName() {
        return brandName;
    }

    public void setBrandName(String brandName) {
        this.brandName = brandName;
    }

    public Integer getCount() {
        return count;
    }

    public void setCount(Integer count) {
        this.count = count;
    }

    public String getImplementingParty() {
        return implementingParty;
    }

    public void setImplementingParty(String implementingParty) {
        this.implementingParty = implementingParty;
    }

    public String getContacts() {
        return contacts;
    }

    public void setContacts(String contacts) {
        this.contacts = contacts;
    }

    public String getContactWay() {
        return contactWay;
    }

    public void setContactWay(String contactWay) {
        this.contactWay = contactWay;
    }

    public String getActivityForms() {
        return activityForms;
    }

    public void setActivityForms(String activityForms) {
        this.activityForms = activityForms;
    }

    public Long getActivityAmount() {
        return activityAmount;
    }

    public void setActivityAmount(Long activityAmount) {
        this.activityAmount = activityAmount;
    }

    public Long getCompanyAmount() {
        return companyAmount;
    }

    public void setCompanyAmount(Long companyAmount) {
        this.companyAmount = companyAmount;
    }

    public String getNotes() {
        return notes;
    }

    public void setNotes(String notes) {
        this.notes = notes;
    }

    public Long getItemBalance() {
        return itemBalance;
    }

    public void setItemBalance(Long itemBalance) {
        this.itemBalance = itemBalance;
    }

    public String getAuditNotes() {
        return auditNotes;
    }

    public void setAuditNotes(String auditNotes) {
        this.auditNotes = auditNotes;
    }

    public String getCreateId() {
        return createId;
    }

    public void setCreateId(String createId) {
        this.createId = createId;
    }

    public String getCreateName() {
        return createName;
    }

    public void setCreateName(String createName) {
        this.createName = createName;
    }

    public Date getCreateDate() {
        return createDate;
    }

    public void setCreateDate(Date createDate) {
        this.createDate = createDate;
    }

    public String getModifyId() {
        return modifyId;
    }

    public void setModifyId(String modifyId) {
        this.modifyId = modifyId;
    }

    public String getModifyName() {
        return modifyName;
    }

    public void setModifyName(String modifyName) {
        this.modifyName = modifyName;
    }

    public Date getModifyDate() {
        return modifyDate;
    }

    public void setModifyDate(Date modifyDate) {
        this.modifyDate = modifyDate;
    }
}
